==> nextcloud-25.0.1.zip: nextcloud/apps/circles/l10n/zh_HK.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "圈子",
    "Circles' files" : "圈子的檔案",
    "Select circles to filter by" : "選擇來作篩選的圈子",
    "No circles found" : "未找到任何圈子",
    "Please select circles to filter by" : "請選擇來作篩選的圈子",
    "No files found for the selected circles" : "所選圈子裹沒有任何檔案",
    "You created the circle {circle}" : "您創建了圈子 {circle}",
    "{author} created the circle {circle}" : "{author} 創建了圈子 {circle}",
    "You deleted {circle}" : "您刪除了 {circle}",
    "{author} deleted {circle}" : "{author} 已刪除 {circle}",
    "You linked {group} to {circle}" : "您已將 {group} 連結到 {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} 已將 {group} 連接到 {circle}",
    "You unlinked {group} from {circle}" : "您已將 {group} 從 {circle} 中斷開",
    "{group} has been unlinked from {circle} by {author}" : "{author} 已將 {group} 從 {circle} 中斷開",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "您已將 {circle} 中的群組 {group} 的級別修改為 %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} 已將 {circle} 中的群組 {group} 的級別修改為 %1$s",
    "You sent a request to link {circle} with {remote}" : "您發送了一個請求，將 {circle} 與 {remote} 連結",
    "{author} sent a request to link {circle} with {remote}" : "{author} 發送了一個請求，將 {circle} 與 {remote} 連結",
    "{remote} requested a link with {circle}" : "{remote} 要求與 {circle} 連結",
    "The request to link {circle} with {remote} has been rejected" : "將 {circle} 與 {remote} 連結起來的請求已被拒絕",
    "The request to link {remote} with {circle} has been canceled remotely" : "將 {remote} 與 {circle} 連結起來的請求已被遠程取消",
    "The request to link {circle} with {remote} has been accepted" : "{circle} 與 {remote} 連結起來的請求已被接受",
    "You dismissed the request to link {remote} with {circle}" : "您駁回了將 {remote} 與 {circle} 連結的請求",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} 駁回了將 {remote} 與 {circle} 連結起來的請求",
    "You canceled the request to link {circle} with {remote}" : "您取消了將 {circle} 與 {remote} 連結的請求",
    "{author} canceled the request to link {circle} with {remote}" : "{author} 取消了將 {circle} 與 {remote} 連結的請求",
    "You accepted the request to link {remote} with {circle}" : "接受了 {remote} 與 {circle} 連結的請求",
    "{author} accepted the request to link {remote} with {circle}" : "{author} 接受了 {remote} 與 {circle} 連結的請求",
    "A link between {circle} and {remote} is now up and running" : "{circle} 和 {remote} 之間的連結現已啟動並運行",
    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} 和 {remote} 之間的連結已被遠程關閉",
    "You closed the link between {circle} and {remote}" : "您關閉了 {circle} 和 {remote} 之間的連結",
    "{author} closed the link between {circle} and {remote}" : "{author} 關閉了 {circle} 和 {remote} 之間的連結",
    "You joined {circle}" : "您已經加入了 {circle}",
    "{member} joined {circle}" : "{member} 加入了 {circle}",
    "You accepted the invitation to join {circle}" : "您接受邀請加入 {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} 接受邀請加入 {circle}",
    "You added {member} as member to {circle}" : "您已將 {member} 加入 {circle}",
    "You have been added as member to {circle} by {author}" : "您已被 {author} 添加為 {circle} 的成員",
    "{member} has been added as member to {circle} by {author}" : "{member} 已被 {author} 添加為 {circle} 的成員",
    "You added {external} to {circle}" : "您已將 {external} 添加到 {circle}",
    "{external} has been added to {circle} by {author}" : "{external} 已由 {author} 添加到 {circle}",
    "You accepted {member}'s request to join {circle}" : "您接納  {member} 的請求加入 {circle}",
    "Your request to join {circle} has been accepted by {author}" : "您加入 {circle} 的請求已被 {author} 接受",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} 加入 {circle} 的請求已被 {author} 接納 ",
    "You left {circle}" : "您離開了 {circle}",
    "{member} left {circle}" : "{member} 離開了 {circle}",
    "You declined the invitation to join {circle}" : "您拒絕了加入 {circle} 的邀請",
    "{member} declined an invitation to join {circle}" : "{member} 拒絕加入 {circle}",
    "You cancelled your request to join {circle}" : "您取消了加入 {circle} 的請求",
    "{member} cancelled his request to join {circle}" : "{member} 取消了他加入 {circle} 的請求",
    "You removed {member} from {circle}" : "您已從 {circle} 刪除 {member}",
    "You have been removed from {circle} by {author}" : "您已被 {author} 移出 {circle}",
    "{member} has been removed from {circle} by {author}" : "{member} 已被 {author} 從 {circle} 移除",
    "You removed {external} from {circle}" : "您已從 {circle} 移除了 {external}",
    "{external} has been removed from {circle} by {author}" : "{external} 已由 {author} 從 {circle} 移除",
    "You cancelled {member}'s invitation to join {circle}" : "您已取消 {member} 加入 {circle} 的邀請",
    "Your invitation to join {circle} has been cancelled by {author}" : "您加入 {circle} 的邀請已被 {author} 取消",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 已取消 {member} 加入 {circle} 的邀請",
    "You dismissed {member}'s request to join {circle}" : "{member} 加入 {circle} 的請求已被您駁回",
    "Your request to join {circle} has been dismissed by {author}" : "您加入 {circle} 的請求已被 {author} 駁回",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} 加入 {circle} 的請求已被 {author} 駁回",
    "You invited {member} to join {circle}" : "您邀請 {member} 加入 {circle}",
    "You have been invited to join {circle} by {author}" : "{author} 邀請您加入 {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} 已被 {author} 邀請參加 {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "您將 {circle} 中的 {member} 的級別更改為 %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} 將 {circle} 的級別更改為 %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 將 {circle} 的 {member} 的級別更改為 %1$s",
    "You sent a request to join {circle}" : "您發送了加入 {circle} 的請求",
    "{member} sent a request to join {circle}" : "{member} 發送了加入 {circle} 的請求",
    "You are the new owner of {circle}" : "您是 {circle} 的新擁有者",
    "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新擁有者",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "當出現發生在一個您是其中一員的<strong>圈子</strong>的事件時",
    "Any important event in a <strong>Circle</strong> you are moderating" : "您正在<strong>圈子</strong>中主持的任何重要事件",
    "On global events happening in any <strong>Circle</strong>" : "當出現發生在任意<strong>圈子</strong>中的全局事件時",
    "Single" : "單則",
    "Personal" : "個人",
    "System" : "系统",
    "Visible" : "可見",
    "Open" : "開啟",
    "Invite" : "邀請",
    "Join Request" : "加入要求",
    "Friends" : "朋友",
    "Password Protected" : "密碼保護",
    "No Owner" : "無所有者",
    "Hidden" : "隱藏",
    "Backend" : "後端系統",
    "Local" : "近端",
    "Root" : "根",
    "Circle Invite" : "社交圈子邀請",
    "Federated" : "已聯盟",
    "Mount point" : "掛載點",
    "Nextcloud Group" : "Nextcloud 群組",
    "Email Address" : "電郵地址",
    "Contact" : "聯絡人",
    "Circle" : "社交圈子",
    "Nextcloud App" : "Nextcloud 應用程式",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "所有者",
    "%s shared »%s« with you." : "%s 已共享 »%s« 給您。",
    "%s shared »%s« with \"%s\"." : "%s 已共享 »%s« ，通過 \"%s\"。",
    "%s on %s" : "%s上%s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 對您共享了 »%2$s«。\n您應已收到一封單獨的帶有訪問連結的電郵。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s 對您共享了 »%2$s«。您應已收到一封單獨的帶有訪問連結的電郵。",
    "Password to access »%1$s« shared to you by %2$s" : "用於訪問 %2$s 共享給您的 »%1$s« 的密碼",
    "Password to access »%s«" : "訪問 »%s« 的密碼",
    "It is protected with the following password:" : "其已被以下密碼保護：",
    "%1$s via %2$s" : "%1$s 通過 %2$s",
    "Click the button below to open it." : "點擊下面的按鈕打開它。",
    "Open »%s«" : "打開 »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s 對您共享了多個文件。\n您應已收到一封單獨的帶有訪問連結的電郵。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s 對您共享了多個文件。您應已收到一封單獨的帶有訪問連結的電郵。",
    "Password to access files shared to you by %1$s" : "使用密碼訪問由 %1$s 共享給您的文件",
    "Password to access files" : "用以訪問文件的密碼",
    "%s shared multiple files with \"%s\"." : "%s 與 \"%s\" 共享了多個檔案。",
    "%s shared multiple files with you." : "%s 對您共享了多個文件。",
    "Boot up" : "啟動",
    "Initialisation Nextcloud" : "初始化 Nextcloud",
    "Initialisation Circles App" : "初始化圈子應用程式",
    "Fresh installation status" : "全新安裝狀態",
    "Building Local Database" : "建立近端數據庫",
    "Testing Basic Circle Creation" : "測試基本圈子創建",
    "Adding local users and moderators" : "添加近端用戶和主持人",
    "Circle not found" : "找不到圈子",
    "Circle not found " : "找不到圈子",
    "A circle with that name exists" : "存在具有該名稱的圈子",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "您的管理員至少允許一種類型的圈子，否則您不能使用“圈子”應用程序",
    "This member does not exist" : "此成員不存在",
    "Federated link not found" : "未找到聯合雲連結",
    "This feature is not available for personal circles" : "此功能不適用於個人圈子",
    "The circle is not federated" : "圈子沒有聯合",
    "You cannot join this circle" : "您不能加入此圈子",
    "This member is not a moderator" : "此成員不是管理員",
    "Insufficient privileges" : "權限不足",
    "This member is the owner of the circle" : "此成員是圈子的所有者",
    "Level cannot be changed for this type of member" : "不能更改此類型成員的級別",
    "You are already a member of this circle" : "您已經是此圈子的成員",
    "You have been blocked from this circle" : "您被限制加入此圈子",
    "%s (Circle owned by %s)" : "%s（由 %s 擁有的社交圈子）",
    "You are now a member of the Circle \"%2$s\"" : "您現在是\"%2$s\" 圈子的一員了",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s 已邀請您加入圈子 \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s發送了一條加入\"%2$s\" 圈子的請求",
    "Accept" : "接受",
    "Refuse" : "拒絕",
    "Leave the circle" : "離開圈子",
    "%s" : "%s",
    "Personal Circle" : "個人圈子",
    "%s owned by %s" : "%s 擁有的 %s",
    "You need a specify a type of circle" : "您需要指定一種類型的圈子",
    "This member is not the owner of the circle" : "此成員不是圈子的所有者",
    "This member is not an admin of the circle" : "該成員不是此圈子的管理員",
    "Group contains too many members" : "群組包含太多成員",
    "This group does not exist" : "該群組不存在",
    "This group is already linked to the circle" : "此群組已經連結到該圈子",
    "You cannot edit level in a personal circle" : "您無法編輯個人圈子中的級別",
    "Group cannot be set as owner of a circle" : "群組不能設置為圈子的所有者",
    "now" : "現在",
    "Email format is not valid" : "電子郵件格式無效",
    "This contact is not available" : "此聯繫人不可用",
    "You have no permission to create a new circle" : "您沒有權限來創建新社交圈子",
    "%s shared a file with \"%s\"." : "%s 與「%s」分享了一個檔案。",
    "%s shared a file with you." : "%s 與您分享了檔案。",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 和您分享了一些内容。\n您應已收到一封帶有訪問連結的電郵。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 和您分享了一些内容。您應已收到一封帶有訪問連結的電郵。",
    "Password to access content shared with you by %1$s" : "使用密碼訪問由 %1$s 與您分享的内容",
    "Password to access content" : "用以訪問内容的密碼",
    "This item is already shared with this circle" : "已和這社交圈子分享了此項目",
    "Could not find share" : "找不到分享",
    "Bring cloud-users closer together." : "把雲端用戶連接到一起。",
    "No files in here" : "此處沒有任何檔案",
    "No entries found in this folder" : "此資料夾中無項目",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Nextcloud User" : "Nextcloud 用戶",
    "This user is already a member of the circle" : "此用戶已經是圈子的成員",
    "The user is already a member of this circle" : "此用戶已經是此圈子的成員",
    "The user has already been invited into this circle" : "用戶已被邀請進入此圈子",
    "This user does not exist" : "此用戶不存在",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "圈子允許您的用戶創建自己的用戶/同事/朋友群組。\n然後，其他應用程式都可以將這些用戶群組（或“圈子”）用於共享目的。"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.10rc1.zip: nextcloud/apps/circles/l10n/zh_HK.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "團隊",
    "You created the team {circle}" : "您創建了團隊 {circle}",
    "{author} created the team {circle}" : "{author} 創建了團隊 {circle}",
    "You deleted {circle}" : "您刪除了 {circle}",
    "{author} deleted {circle}" : "{author} 已刪除 {circle}",
    "You made {member} join {circle}" : "您讓 {member} 加入了 {circle}",
    "{author} made {member} join {circle}" : "{author} 讓 {member} 加入了 {circle}",
    "You added team {member} as member to {circle}" : "您已將團隊 {member} 添加為 {circle} 的成員",
    "{author} added team {member} as member to {circle}" : "{author}  已將團隊 {member} 添加為 {circle} 的成員",
    "You made {member} leave {circle}" : "您讓 {member} 離開了 {circle}",
    "{author} made {member} leave {circle}" : "{author} 讓 {member} 離開了 {circle}",
    "You removed {member} from {circle}" : "您已從 {circle} 刪除 {member}",
    "{author} removed {member} from {circle}" : "{author} 已從 {circle} 刪除 {member}",
    "You joined {circle}" : "您已經加入了 {circle}",
    "{member} joined {circle}" : "{member} 加入了 {circle}",
    "You accepted the invitation to join {circle}" : "您接受邀請加入 {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} 接受邀請加入 {circle}",
    "You added {member} as member to {circle}" : "您已將 {member} 加入 {circle}",
    "You have been added as member to {circle} by {author}" : "您已被 {author} 添加為 {circle} 的成員",
    "{member} has been added as member to {circle} by {author}" : "{member} 已被 {author} 添加為 {circle} 的成員",
    "You added {external} to {circle}" : "您已將 {external} 添加到 {circle}",
    "{external} has been added to {circle} by {author}" : "{external} 已由 {author} 添加到 {circle}",
    "You accepted {member}'s request to join {circle}" : "您接納  {member} 的請求加入 {circle}",
    "Your request to join {circle} has been accepted by {author}" : "您加入 {circle} 的請求已被 {author} 接受",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} 加入 {circle} 的請求已被 {author} 接納 ",
    "You left {circle}" : "您離開了 {circle}",
    "{member} left {circle}" : "{member} 離開了 {circle}",
    "You declined the invitation to join {circle}" : "您拒絕了加入 {circle} 的邀請",
    "{member} declined an invitation to join {circle}" : "{member} 拒絕加入 {circle}",
    "You cancelled your request to join {circle}" : "您取消了加入 {circle} 的請求",
    "{member} cancelled a request to join {circle}" : "{member} 取消了加入 {circle} 的請求",
    "You have been removed from {circle} by {author}" : "您已被 {author} 移出 {circle}",
    "{member} has been removed from {circle} by {author}" : "{member} 已被 {author} 從 {circle} 移除",
    "You removed {external} from {circle}" : "您已從 {circle} 移除了 {external}",
    "{external} has been removed from {circle} by {author}" : "{external} 已由 {author} 從 {circle} 移除",
    "You cancelled {member}'s invitation to join {circle}" : "您已取消 {member} 加入 {circle} 的邀請",
    "Your invitation to join {circle} has been cancelled by {author}" : "您加入 {circle} 的邀請已被 {author} 取消",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 已取消 {member} 加入 {circle} 的邀請",
    "You dismissed {member}'s request to join {circle}" : "{member} 加入 {circle} 的請求已被您駁回",
    "Your request to join {circle} has been dismissed by {author}" : "您加入 {circle} 的請求已被 {author} 駁回",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} 加入 {circle} 的請求已被 {author} 駁回",
    "You invited {member} to join {circle}" : "您邀請 {member} 加入 {circle}",
    "You have been invited to join {circle} by {author}" : "{author} 邀請您加入 {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} 已被 {author} 邀請參加 {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "您將 {circle} 中的 {member} 的級別更改為 %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} 將 {circle} 的級別更改為 %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 將 {circle} 的 {member} 的級別更改為 %1$s",
    "You sent a request to join {circle}" : "您發送了加入 {circle} 的請求",
    "{member} sent a request to join {circle}" : "{member} 發送了加入 {circle} 的請求",
    "You are the new owner of {circle}" : "您是 {circle} 的新擁有者",
    "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新擁有者",
    "On events happening in a <strong>team</strong> of which you are a member" : "當出現發生在一個您是其中一員的<strong>團隊</strong>的事件時",
    "Any important event in a <strong>team</strong> you are moderating" : "您正在<strong>團隊</strong>中主持的任何重要事件",
    "On global events happening in any <strong>team</strong>" : "當出現發生在任意<strong>團隊</strong>中的全局事件時",
    "Single" : "單則",
    "Personal" : "個人",
    "System" : "系统",
    "Visible" : "可見",
    "Open" : "開啟",
    "Invite" : "邀請",
    "Join request" : "請求加入",
    "Friends" : "朋友",
    "Password protected" : "密碼保護",
    "No Owner" : "無所有者",
    "Hidden" : "隱藏",
    "Backend" : "後端系統",
    "Local" : "近端",
    "Root" : "根",
    "Team invite" : "團隊邀請",
    "Federated" : "已聯盟",
    "Mount point" : "掛載點",
    "Nextcloud Account" : "Nextcloud 帳戶",
    "Nextcloud Group" : "Nextcloud 群組",
    "Email address" : "電郵地址",
    "Contact" : "聯絡人",
    "Team" : "團隊",
    "Nextcloud App" : "Nextcloud 應用程式",
    "Teams App" : "團隊應用程式",
    "Admin Command Line" : "管理員命令列",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "所有者",
    "%s shared »%s« with you." : "%s 已共享 »%s« 給您。",
    "%s shared »%s« with \"%s\"." : "%s 已共享 »%s« ，通過 \"%s\"。",
    "%s on %s" : "%s上%s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 對您共享了 »%2$s«。\n您應已收到一封單獨的帶有訪問連結的電郵。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s 對您共享了 »%2$s«。您應已收到一封單獨的帶有訪問連結的電郵。",
    "Password to access »%1$s« shared to you by %2$s" : "用於訪問 %2$s 共享給您的 »%1$s« 的密碼",
    "Password to access »%s«" : "訪問 »%s« 的密碼",
    "It is protected with the following password:" : "其已被以下密碼保護：",
    "%1$s via %2$s" : "%1$s 通過 %2$s",
    "Click the button below to open it." : "點擊下面的按鈕打開它。",
    "Open »%s«" : "打開 »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s 對您共享了多個檔案。\n您應已收到一封單獨的帶有訪問連結的電郵。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s 對您共享了多個檔案。您應已收到一封單獨的帶有訪問連結的電郵。",
    "Password to access files shared to you by %1$s" : "使用密碼訪問由 %1$s 共享給您的檔案",
    "Password to access files" : "用以訪問文件的密碼",
    "%s shared multiple files with \"%s\"." : "%s 與 \"%s\" 共享了多個檔案。",
    "%s shared multiple files with you." : "%s 對您共享了多個文件。",
    "Boot up" : "啟動",
    "Nextcloud Initialization" : "初始 Nextcloud",
    "Circles App Initialization" : "初始 Circles 應用程式",
    "Fresh installation status" : "全新安裝狀態",
    "Building Local Database" : "建立近端數據庫",
    "Testing Basic Circle Creation" : "測試基本圈子創建",
    "Adding local users and moderators" : "添加近端用戶和主持人",
    "Show all teams" : "顯示所有團隊",
    "Create a new team" : "創建新團隊",
    "Files" : "檔案",
    "This feature is not available for personal circles" : "此功能不適用於個人圈子",
    "The team is not federated" : "團隊沒有聯合",
    "You cannot join this team" : "您不能加入此團隊",
    "This member is not a moderator" : "此成員不是管理員",
    "Insufficient privileges" : "權限不足",
    "This member does not exist" : "此成員不存在",
    "This member is the owner of the team" : "此成員是團隊的所有者",
    "Level cannot be changed for this type of member" : "不能更改此類型成員的級別",
    "You are already a member of this circle" : "您已經是此圈子的成員",
    "You have been blocked from this circle" : "您被限制加入此圈子",
    "The account is already a member of this circle" : "該帳戶已經是圈子的成員",
    "The account has already been invited into this circle" : "該帳戶已被邀請加入此圈子",
    "%s (Team owned by %s)" : "%s（由 %s 擁有的團隊）",
    "You are now a member of the Team \"%2$s\"" : "您現在是團隊「%2$s」的成員了",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s 已邀請您加入團隊 「%2$s」",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s 傳送了成為團隊「%2$s」成員的請求",
    "Accept" : "接受",
    "Refuse" : "拒絕",
    "Leave the team" : "離開團隊",
    "%s" : "%s",
    "Personal team" : "個人團隊",
    "%s owned by %s" : "%s 擁有的 %s",
    "You have no permission to create a new team" : "您沒有權限來創建新團隊",
    "%s shared a file with \"%s\"." : "%s 與「%s」分享了一個檔案。",
    "%s shared a file with you." : "%s 與您分享了檔案。",
    "%1$s shared %2$s with %3$s" : "%1$s 與 %3$s 分享了 %2$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s 與「%3$s」分享了 %2$s",
    "Open %s" : "打開 %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 和您分享了一些内容。\n您應已收到一封帶有訪問連結的電郵。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 和您分享了一些内容。您應已收到一封帶有訪問連結的電郵。",
    "Password to access content shared with you by %1$s" : "使用密碼訪問由 %1$s 與您分享的内容",
    "Password to access content" : "用以訪問内容的密碼",
    "This item is already shared with this team" : "已和這團隊分享了此項目",
    "Bring cloud-users closer together." : "把雲端用戶連接到一起。",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "團隊允許人們創建自己的人/同事/朋友群。\n然後，其他應用程式可以使用這些群組來進行共享。",
    "Failed to load teams" : "載入團隊失敗",
    "Try again" : "重试",
    "No teams found" : "找不到團隊",
    "Join or create teams to see them here." : "加入或建立團隊即可在此檢視。",
    "Create your first team" : "建立您的第一個團隊",
    "Loading…" : "加載中…",
    "More teams" : "更多團隊",
    "No files in here" : "此處沒有任何檔案",
    "No entries found in this folder" : "此資料夾中無項目",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Shared to Circles" : "分享到圈子",
    "Circle" : "社交圈子"
},
"nplurals=1; plural=0;");
